@@ -34,15 +34,13 @@ def fetch_genes(filename, suffix=None):
                 lower.write(line)
 
 def fetch_chr22(filename):
-    from subprocess import Popen, PIPE
+    import requests
+    import gzip
 
-    grch36 = 'ftp://ftp-trace.ncbi.nih.gov//1000genomes/ftp/pilot_data/technical/reference/human_b36_male.fa.gz'
-    curl = Popen(['curl', '-s', grch36], stdout=PIPE)
-    gz = Popen(['gzip', '-dcq'], stdin=curl.stdout, stdout=PIPE)
-    with gz.stdout as remote:
-        with open(filename, 'w') as fasta:
+    with requests.get('https://ftp-trace.ncbi.nih.gov/1000genomes/ftp/pilot_data/technical/reference/human_b36_male.fa.gz') as compressed:
+        with open(filename, 'w') as fasta, gzip.GzipFile(fileobj=compressed.raw) as gz:
             chr22 = False
-            for line in remote:
+            for line in gz:
                 if line[0:3] == '>22':
                     fasta.write(line)
                     chr22 = True
@@ -66,17 +64,20 @@ def fake_chr22(filename):
         fake_file.write('N' * mod_70 + '\n')
 
 def bgzip_compress_fasta(filename):
-    from subprocess import call
-    call(' '.join(['bgzip', '-c', filename, '>', filename + '.gz']), shell=True)
-
+    from Bio.bgzf import BgzfWriter
+    with BgzfWriter(filename=filename + '.gz') as compressed, open(filename, 'r') as fasta:
+        for line in fasta:
+            compressed.write(line)
 
 def fetch_chr22_vcf(filename):
-    from subprocess import call
-    call(['curl', '-s', 'ftp://ftp-trace.ncbi.nih.gov//1000genomes/ftp/pilot_data/release/2010_07/exon/snps/CEU.exon.2010_03.genotypes.vcf.gz',
-          '-o', filename])
-    call(['curl', '-s', 'ftp://ftp-trace.ncbi.nih.gov//1000genomes/ftp/pilot_data/release/2010_07/exon/snps/CEU.exon.2010_03.genotypes.vcf.gz.tbi',
-          '-o', filename + '.tbi'])
-
+    import requests
+    
+    with requests.get('https://ftp-trace.ncbi.nih.gov/1000genomes/ftp/pilot_data/release/2010_07/exon/snps/CEU.exon.2010_03.genotypes.vcf.gz') as vcf:
+        with open(filename, 'wb') as out:
+            out.write(vcf.content)
+    with requests.get('https://ftp-trace.ncbi.nih.gov/1000genomes/ftp/pilot_data/release/2010_07/exon/snps/CEU.exon.2010_03.genotypes.vcf.gz.tbi') as tbi:
+        with open(filename + '.tbi', 'wb') as out:
+            out.write(tbi.content)
 
 
 if __name__ == "__main__":
